# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2022 data-futures.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Simple IIIF image preview."""

from os.path import splitext

from flask import current_app, render_template
from werkzeug.local import LocalProxy

previewable_extensions = LocalProxy(lambda: current_app.config["IIIF_FORMATS"].keys())

# extensions that can be put in <img> tag - all others converted to jpg
native_extensions = LocalProxy(
    lambda: current_app.config["IIIF_SIMPLE_PREVIEWER_NATIVE_EXTENSIONS"]
)


def can_preview(file):
    """Check if file can be previewed by this previewer.

    :param file: The file to be previewed.
    :returns: Boolean
    """
    # supported_extensions list needs . prefixed -
    supported_extensions = ["." + ext for ext in previewable_extensions]
    return file.has_extensions(*supported_extensions)


def preview(file):
    """Render template.

    :param file: Image file to preview.
    :returns: Rendered template with image from IIIF service.
    """
    ext = splitext(file.filename)[1].lower()[1:]
    format = ext if ext in native_extensions else "jpg"
    size = LocalProxy(lambda: current_app.config["IIIF_SIMPLE_PREVIEWER_SIZE"])

    url = f"{file.data['links']['iiif_base']}/full/{size}/0/default.{format}"
    return render_template(
        current_app.config["IIIF_PREVIEW_TEMPLATE"],
        css_bundles=["iiif-simple-previewer.css"],
        file=file,
        file_url=url,
    )



# -*- coding: utf-8 -*-
#
# Copyright (C) 2023 CERN.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Invenio administration users view module."""
from functools import partial

from flask import current_app
from invenio_administration.views.base import (
    AdminResourceDetailView,
    AdminResourceListView,
)
from invenio_i18n import lazy_gettext as _
from invenio_search_ui.searchconfig import search_app_config

USERS_ITEM_LIST = {
    "user": {"text": _("User"), "order": 2, "width": 3},
    "username": {"text": _("Username"), "order": 3, "width": 2},
    "email": {"text": _("Email"), "order": 4, "width": 2},
    "status": {"text": _("Status"), "order": 5, "width": 1},
    "created": {"text": _("Created"), "order": 6, "width": 1},
    "updated": {"text": _("Updated"), "order": 6, "width": 1},
    "links": {"text": "", "order": 7, "width": 1},
}

USERS_ITEM_DETAIL = {
    "id": {"text": _("ID"), "order": 1, "width": 1},
    "username": {"text": _("Username"), "order": 3, "width": 2},
    "email": {"text": _("Email"), "order": 4, "width": 1},
    "domain": {"text": _("Domain "), "order": 5, "width": 1},
    "status": {"text": _("Status"), "order": 6, "width": 1},
    "visibility": {"text": _("Visibility"), "order": 7, "width": 1},
    "active": {"text": _("Active"), "order": 8, "width": 1},
    "confirmed_at": {"text": _("Confirmed at"), "order": 9, "width": 1},
    "verified_at": {"text": _("Verified at"), "order": 10, "width": 1},
    "blocked_at": {"text": _("Blocked at"), "order": 11, "width": 1},
    "created": {"text": _("Created"), "order": 12, "width": 2},
    "updated": {"text": _("Updated"), "order": 13, "width": 2},
}


# List of the columns displayed on the user list and user details


class UsersListView(AdminResourceListView):
    """Configuration for users sets list view."""

    api_endpoint = "/users/all"
    extension_name = "invenio-users-resources"
    name = "users"
    resource_config = "users_resource"
    title = "User management"
    menu_label = "Users"
    category = "User management"
    pid_path = "id"
    icon = "users"

    display_search = True
    display_delete = False
    display_edit = False
    display_create = False

    item_field_list = USERS_ITEM_LIST

    search_config_name = "USERS_RESOURCES_SEARCH"
    search_sort_config_name = "USERS_RESOURCES_SORT_OPTIONS"
    search_facets_config_name = "USERS_RESOURCES_SEARCH_FACETS"
    template = "invenio_app_rdm/administration/users_search.html"

    # These actions are not connected on the frontend -
    # TODO: missing permission based links in resource
    actions = {
        "approve": {
            "text": "Approve",
            "payload_schema": None,
            "order": 1,
        },
        "restore": {
            "text": "Restore",
            "payload_schema": None,
            "order": 2,
        },
        "block": {
            "text": "Block",
            "payload_schema": None,
            "order": 2,
        },
        "Deactivate": {
            "text": "Suspend",
            "payload_schema": None,
            "order": 2,
        },
    }

    @staticmethod
    def disabled():
        """Disable the view on demand."""
        return not current_app.config["USERS_RESOURCES_ADMINISTRATION_ENABLED"]

    def init_search_config(self):
        """Build search view config."""
        return partial(
            search_app_config,
            config_name=self.get_search_app_name(),
            available_facets=current_app.config.get(self.search_facets_config_name),
            sort_options=current_app.config[self.search_sort_config_name],
            endpoint=self.get_api_endpoint(),
            headers=self.get_search_request_headers(),
            initial_filters=[["is_active", 1]],
            hidden_params=[],
            page=1,
            size=15,
        )


class UsersDetailView(AdminResourceDetailView):
    """Configuration for users sets detail view."""

    url = "/users/<pid_value>"
    api_endpoint = "/users/"
    search_request_headers = {"Accept": "application/json"}
    extension_name = "invenio-users-resources"
    name = "User details"
    resource_config = "users_resource"
    title = _("User details")
    display_delete = False
    display_edit = False

    pid_path = "username"
    item_field_list = USERS_ITEM_DETAIL



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 CERN.
#
# Invenio-App-RDM is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Command-line tools for invenio app rdm."""
import click
from flask.cli import with_appcontext
from invenio_access.permissions import system_identity
from invenio_records_resources.proxies import current_service_registry

from .fixtures import FixturesEngine, Pages


@click.group()
def rdm():
    """Invenio app rdm commands."""


@rdm.group()
def pages():
    """Static pages."""


@pages.command("create")
@click.option(
    "-f",
    "--force",
    "force",
    default=False,
    is_flag=True,
    show_default=True,
    help="Creates static pages.",
)
@with_appcontext
def create_static_pages(force):
    """Create static pages."""
    click.secho("Creating static pages...", fg="green")

    Pages().run(force=force)

    click.secho("Created static pages!", fg="green")


@rdm.command("fixtures")
@with_appcontext
def create_fixtures():
    """Create the fixtures."""
    click.secho("Creating required fixtures...", fg="green")

    FixturesEngine().run()

    click.secho("Created required fixtures!", fg="green")


@rdm.command("rebuild-all-indices")
@click.option("-o", "--order", default="")
@with_appcontext
def rebuild_all_indices(order):
    """Schedule reindexing of (all) items for search with optional selecting and ordering."""
    services = current_service_registry._services
    service_names = services.keys()
    services_to_reindex = order.split(",") if order else service_names

    for service_to_reindex in services_to_reindex:
        if service_to_reindex not in service_names:
            click.secho(
                f"Service: '{service_to_reindex}' is not part of available services that can be reindexed",  # noqa
                fg="red",
            )
            click.secho(
                f"You can chose out of these services: {' , '.join(service_names)}",
                fg="red",
            )
            return

    click.secho("Scheduling bulk indexing.", fg="yellow")
    for service_to_reindex in services_to_reindex:
        service = services[service_to_reindex]
        if hasattr(service, "rebuild_index"):
            click.echo(f"Reindexing {service_to_reindex}... ", nl=False)
            service.rebuild_index(system_identity)
            click.secho("Done.", fg="green")



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 CERN.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.
"""Test invenio-app-rdm celery tasks."""


from invenio_app_rdm.tasks import file_integrity_report


def test_task_file_integrity_report(app, invalid_file_instance):
    """Test celery task for file integrity reports."""
    assert invalid_file_instance.last_check is False

    # A report must be generated for the file
    mail = app.extensions.get("mail")
    assert mail

    recipients = "test@invenio.org"
    sender = "test@invenio.org"

    file_name = invalid_file_instance.objects[0].key
    uri = invalid_file_instance.uri
    file_id = invalid_file_instance.id
    file_name = invalid_file_instance.objects[0].key
    checksum = invalid_file_instance.checksum

    with mail.record_messages() as outbox:
        # Configure email and validate that email was sent
        app.config["APP_RDM_FILES_INTEGRITY_REPORT_TEMPLATE"] = "mock_mail.html"
        app.config["APP_RDM_ADMIN_EMAIL_RECIPIENT"] = recipients
        app.config["MAIL_DEFAULT_SENDER"] = sender

        file_integrity_report()
        assert len(outbox) == 1
        mail_sent = outbox[0]
        assert mail_sent.recipients == [recipients]
        assert mail_sent.sender == sender
        assert "Checksum: {}".format(checksum) in mail_sent.body
        assert "URI: {}".format(uri) in mail_sent.body
        assert "ID: {}".format(str(file_id)) in mail_sent.body
        assert "Name: {}".format(file_name) in mail_sent.body


def test_integrity_report_invalid_template(app, invalid_file_instance):
    """Test non-existant e-mail template."""
    assert invalid_file_instance.last_check is False

    mail = app.extensions.get("mail")
    assert mail

    with mail.record_messages() as outbox:
        # Remove the template, no e-mail is sent
        app.config["APP_RDM_FILES_INTEGRITY_REPORT_TEMPLATE"] = None
        file_integrity_report()
        assert len(outbox) == 0


def test_integrity_report_invalid_addresses(app, invalid_file_instance):
    """Test invalid recipient address."""
    assert invalid_file_instance.last_check is False

    mail = app.extensions.get("mail")
    assert mail

    with mail.record_messages() as outbox:
        # Use mock template
        app.config["APP_RDM_FILES_INTEGRITY_REPORT_TEMPLATE"] = "mock_mail.html"

        # Recipient is not set, mail is not sent.
        app.config["APP_RDM_ADMIN_EMAIL_RECIPIENT"] = None
        file_integrity_report()
        assert len(outbox) == 0


def test_integrity_report_default_template(app, invalid_file_instance):
    """Test invalid recipient address."""
    assert invalid_file_instance.last_check is False

    mail = app.extensions.get("mail")
    assert mail

    recipients = "test@invenio.org"
    sender = "test@invenio.org"

    uri = invalid_file_instance.uri
    file_id = invalid_file_instance.id
    file_name = invalid_file_instance.objects[0].key
    checksum = invalid_file_instance.checksum

    with mail.record_messages() as outbox:
        # Use default template
        app.config["APP_RDM_ADMIN_EMAIL_RECIPIENT"] = recipients
        app.config["MAIL_DEFAULT_SENDER"] = sender
        file_integrity_report()
        assert len(outbox) == 1
        mail_sent = outbox[0]
        assert mail_sent.recipients == [recipients]
        assert mail_sent.sender == sender
        assert "Checksum: {}".format(checksum) in mail_sent.body
        assert "URI: {}".format(uri) in mail_sent.body
        assert "ID: {}".format(str(file_id)) in mail_sent.body
        assert "Name: {}".format(file_name) in mail_sent.body



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2016-2022 CERN.
# Copyright (C) 2022 Northwestern University.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Community views."""

from .ui import create_ui_blueprint

__all__ = ("create_ui_blueprint",)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2023 CERN.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.
"""Administration ui views module."""
from flask import Blueprint


def create_ui_blueprint(app):
    """Register blueprint routes on app."""
    blueprint = Blueprint(
        "invenio_app_rdm_administration",
        __name__,
        template_folder="../templates",
        static_folder="../static",
    )

    return blueprint



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 CERN.
#
# Invenio-App-RDM is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Record migration script from InvenioRDM 9.0 to 10.0.

Disclaimer: This script is intended to be executed *only once*, namely when
upgrading from InvenioRDM 9.0 to 10.0!
If this script is executed at any other time, probably the best case scenario
is that nothing happens!
"""

from click import echo, secho
from invenio_db import db
from invenio_oaiserver.models import OAISet


def execute_upgrade():
    """Execute the upgrade from InvenioRDM 9.0 to 10.0.

    Please read the disclaimer on this module before thinking about executing
    this function!
    """
    system_created_sets = OAISet.query.filter(OAISet.spec.like("community-%")).all()

    for system_created_set in system_created_sets:
        echo(f"Updating record: {system_created_set.id}... ", nl=True)
        system_created_set.system_created = True

    echo("Committing to DB", nl=True)
    db.session.commit()
    secho(
        "Data migration completed.",
        fg="green",
    )


# if the script is executed on its own, perform the upgrade
if __name__ == "__main__":
    execute_upgrade()



# -*- coding: utf-8 -*-
#
# Copyright (C) 2019-2024 CERN.
# Copyright (C) 2019-2022 Northwestern University.
# Copyright (C)      2022 TU Wien.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Request views module."""

from flask import g, render_template
from flask_login import current_user, login_required
from invenio_communities.config import COMMUNITIES_ROLES
from invenio_communities.members.services.request import CommunityInvitation
from invenio_communities.proxies import current_identities_cache
from invenio_communities.utils import identity_cache_key
from invenio_communities.views.communities import render_community_theme_template
from invenio_communities.views.decorators import pass_community
from invenio_pidstore.errors import PIDDoesNotExistError
from invenio_rdm_records.proxies import current_rdm_records_service
from invenio_rdm_records.requests import CommunityInclusion, CommunitySubmission
from invenio_rdm_records.resources.serializers import UIJSONSerializer
from invenio_rdm_records.services.generators import CommunityInclusionNeed
from invenio_records_resources.services.errors import PermissionDeniedError
from invenio_requests.customizations import AcceptAction
from invenio_requests.resolvers.registry import ResolverRegistry
from invenio_requests.views.decorators import pass_request
from invenio_users_resources.proxies import current_user_resources
from sqlalchemy.orm.exc import NoResultFound

from ...records_ui.utils import get_external_resources
from ...records_ui.views.decorators import (
    draft_files_service,
    draft_media_files_service,
    files_service,
    media_files_service,
)
from ...records_ui.views.deposits import (
    get_user_communities_memberships,
    load_custom_fields,
)


def _resolve_topic_record(request):
    """Resolve the record in the topic, when it is a draft or a published record."""
    creator_id = request["expanded"].get("created_by", {}).get("id", None)
    user_owns_request = str(creator_id) == str(current_user.id)

    if request["is_closed"] and not user_owns_request:
        return dict(permissions={}, record_ui=None)

    record = None
    # parse the topic field to get the draft/record pid `record:abcd-efgh`
    entity = ResolverRegistry.resolve_entity_proxy(request["topic"])
    pid = entity._parse_ref_dict_id()

    request_type = request["type"]
    is_record_inclusion = request_type == CommunityInclusion.type_id

    try:
        if is_record_inclusion:
            community = request["receiver"]["community"]
            # Get the roles that can curate and in consequence should be able to see the record of the inclusion request
            can_curate_roles = {
                role["name"]
                for role in COMMUNITIES_ROLES
                if role.get("can_curate", False)
            }
            cache_key = identity_cache_key(g.identity)
            user_community_roles = current_identities_cache.get(cache_key)
            for community_id, role in user_community_roles:
                if community_id == community and role in can_curate_roles:
                    # This need should not be reused, see CommunityInclusionReviewers generator docstring for more info
                    community_inclusion_need = CommunityInclusionNeed(
                        pid
                    )  # pid is the record pid
                    g.identity.provides.add(community_inclusion_need)
                    break
            # read published record
            record = current_rdm_records_service.read(g.identity, pid, expand=True)
        else:
            # read draft
            record = current_rdm_records_service.read_draft(
                g.identity, pid, expand=True
            )
    except (NoResultFound, PIDDoesNotExistError):
        # We catch PIDDoesNotExistError because a published record with
        # a soft-deleted draft will raise this error. The lines below
        # will catch the case that a id does not exists and raise a
        # PIDDoesNotExistError that can be handled as 404 in the resource
        # layer.
        try:
            # read published record
            record = current_rdm_records_service.read(g.identity, pid, expand=True)
        except NoResultFound:
            # record tab not displayed when the record is not found
            # the request is probably not open anymore
            pass

    if record:
        record_ui = UIJSONSerializer().dump_obj(record.to_dict())
        permissions = record.has_permissions_to(
            [
                "edit",
                "new_version",
                "manage",
                "update_draft",
                "read_files",
                "review",
                "read",
            ]
        )
        return dict(permissions=permissions, record_ui=record_ui)

    return dict(permissions={}, record_ui=None)


def _resolve_record_or_draft_files(record, request):
    """Resolve the record's or draft's files."""
    request_type = request["type"]
    is_record_inclusion = request_type == CommunityInclusion.type_id
    if record and record["files"]["enabled"]:
        record_pid = record["id"]
        try:
            if is_record_inclusion:
                files = files_service().list_files(id_=record_pid, identity=g.identity)
            else:
                files = draft_files_service().list_files(
                    id_=record_pid, identity=g.identity
                )
        except NoResultFound:
            files = files_service().list_files(id_=record_pid, identity=g.identity)
        return files.to_dict()
    return None


def _resolve_record_or_draft_media_files(record, request):
    """Resolve the record's or draft's media files."""
    request_type = request["type"]
    is_record_inclusion = request_type == CommunityInclusion.type_id
    if record and record["media_files"]["enabled"]:
        record_pid = record["id"]
        try:
            if is_record_inclusion:
                media_files = media_files_service().list_files(
                    id_=record_pid, identity=g.identity
                )
            else:
                media_files = draft_media_files_service().list_files(
                    id_=record_pid, identity=g.identity
                )
        except NoResultFound:
            media_files = media_files_service().list_files(
                id_=record_pid, identity=g.identity
            )
        return media_files.to_dict()
    return None


@login_required
@pass_request(expand=True)
def user_dashboard_request_view(request, **kwargs):
    """User dashboard request details view."""
    avatar = current_user_resources.users_service.links_item_tpl.expand(
        g.identity, current_user
    )["avatar"]

    request_type = request["type"]
    request_is_accepted = request["status"] == AcceptAction.status_to

    has_topic = request["topic"] is not None
    has_record_topic = has_topic and "record" in request["topic"]
    has_community_topic = has_topic and "community" in request["topic"]

    if has_record_topic:
        topic = _resolve_topic_record(request)
        record = topic["record_ui"]  # None when draft
        is_draft = record["is_draft"] if record else False

        files = _resolve_record_or_draft_files(record, request)
        media_files = _resolve_record_or_draft_media_files(record, request)
        return render_template(
            f"invenio_requests/{request_type}/index.html",
            base_template="invenio_app_rdm/users/base.html",
            user_avatar=avatar,
            invenio_request=request.to_dict(),
            record=record,
            permissions=topic["permissions"],
            is_preview=is_draft,  # preview only when draft
            is_draft=is_draft,
            request_is_accepted=request_is_accepted,
            files=files,
            media_files=media_files,
            is_user_dashboard=True,
            custom_fields_ui=load_custom_fields()["ui"],
            user_communities_memberships=get_user_communities_memberships(),
            external_resources=get_external_resources(record),
            include_deleted=False,
        )

    elif has_community_topic or not has_topic:
        return render_template(
            f"invenio_requests/{request_type}/user_dashboard.html",
            base_template="invenio_app_rdm/users/base.html",
            user_avatar=avatar,
            invenio_request=request.to_dict(),
            request_is_accepted=request_is_accepted,
            permissions={},
            include_deleted=False,
        )

    topic = _resolve_topic_record(request)
    record = topic["record_ui"]

    return render_template(
        f"invenio_requests/{request_type}/index.html",
        base_template="invenio_app_rdm/users/base.html",
        user_avatar=avatar,
        record=record,
        permissions=topic["permissions"],
        invenio_request=request.to_dict(),
        request_is_accepted=request_is_accepted,
        include_deleted=False,
    )


@login_required
@pass_request(expand=True)
@pass_community(serialize=True)
def community_dashboard_request_view(request, community, community_ui, **kwargs):
    """Community dashboard requests details view."""
    avatar = current_user_resources.users_service.links_item_tpl.expand(
        g.identity, current_user
    )["avatar"]

    request_type = request["type"]

    is_draft_submission = request_type == CommunitySubmission.type_id
    is_record_inclusion = request_type == CommunityInclusion.type_id
    is_member_invitation = request_type == CommunityInvitation.type_id
    request_is_accepted = request["status"] == AcceptAction.status_to

    if is_draft_submission or is_record_inclusion:
        permissions = community.has_permissions_to(
            ["update", "read", "search_requests", "search_invites"]
        )

        topic = _resolve_topic_record(request)
        record = topic["record_ui"]  # None when draft
        is_draft = record["is_draft"] if record else False

        permissions.update(topic["permissions"])
        files = _resolve_record_or_draft_files(record, request)
        media_files = _resolve_record_or_draft_media_files(record, request)
        return render_community_theme_template(
            f"invenio_requests/{request_type}/index.html",
            theme=community.to_dict().get("theme", {}),
            base_template="invenio_communities/details/base.html",
            invenio_request=request.to_dict(),
            record=record,
            community=community_ui,
            permissions=permissions,
            is_preview=is_draft,  # preview only when draft
            is_draft=is_draft,
            request_is_accepted=request_is_accepted,
            files=files,
            media_files=media_files,
            user_avatar=avatar,
            custom_fields_ui=load_custom_fields()["ui"],
            user_communities_memberships=get_user_communities_memberships(),
            external_resources=get_external_resources(record),
            include_deleted=False,
        )

    elif is_member_invitation:
        permissions = community.has_permissions_to(
            ["update", "read", "search_requests", "search_invites"]
        )
        if not permissions["can_search_invites"]:
            raise PermissionDeniedError()

        return render_community_theme_template(
            f"invenio_requests/{request_type}/community_dashboard.html",
            theme=community.to_dict().get("theme", {}),
            base_template="invenio_communities/details/members/base.html",
            invenio_request=request.to_dict(),
            community=community.to_dict(),
            permissions=permissions,
            request_is_accepted=request_is_accepted,
            user_avatar=avatar,
            include_deleted=False,
        )



# -*- coding: utf-8 -*-
#
# Copyright (C) 2019-2024 CERN.
# Copyright (C) 2019-2022 Northwestern University.
# Copyright (C)      2022 TU Wien.
#
# Invenio App RDM is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.
"""Request views module."""

from flask import g, redirect, request, url_for
from invenio_communities.views.communities import render_community_theme_template
from invenio_communities.views.decorators import pass_community
from invenio_rdm_records.proxies import current_community_records_service
from invenio_rdm_records.resources.serializers import UIJSONSerializer
from invenio_records_resources.services.errors import PermissionDeniedError


@pass_community(serialize=True)
def communities_detail(pid_value, community, community_ui):
    """Community detail page."""
    permissions = community.has_permissions_to(
        ["update", "read", "search_requests", "search_invites", "moderate"]
    )
    endpoint = "/api/communities/{pid_value}/records"

    return render_community_theme_template(
        "invenio_communities/records/index.html",
        theme=community_ui.get("theme", {}),
        community=community,
        community_ui=community_ui,
        # Pass permissions so we can disable partially UI components
        # e.g Settings tab
        permissions=permissions,
        active_community_header_menu_item="search",
        endpoint=endpoint.format(pid_value=community.to_dict()["id"]),
    )


@pass_community(serialize=True)
def communities_home(pid_value, community, community_ui):
    """Community home page."""
    query_params = request.args

    permissions = community.has_permissions_to(
        [
            "update",
            "read",
            "search_requests",
            "search_invites",
            "moderate",
        ]
    )
    if not permissions["can_read"]:
        raise PermissionDeniedError()

    theme_enabled = community._record.theme and community._record.theme.get(
        "enabled", False
    )

    if query_params or not theme_enabled:
        url = url_for(
            "invenio_app_rdm_communities.communities_detail",
            pid_value=community.data["slug"],
            **request.args
        )
        return redirect(url)

    if theme_enabled:
        recent_uploads = current_community_records_service.search(
            community_id=pid_value,
            identity=g.identity,
            params={
                "sort": "newest",
                "size": 3,
            },
            expand=True,
        )

        records_ui = UIJSONSerializer().dump_list(recent_uploads.to_dict())["hits"][
            "hits"
        ]

        return render_community_theme_template(
            "invenio_communities/details/home/index.html",
            theme=community_ui.get("theme", {}),
            community=community_ui,
            permissions=permissions,
            records=records_ui,
        )
